Polygons are rasterized and a Weighted Voronoi Diagram is calculated.
get_single_voronoi(
core,
point,
buffer = NULL,
weight_column = NULL,
class_columns = NULL,
res = 1,
warn = TRUE
)Polygon containing a core plot boundary. core has to
be a length one sfc_POLYGON-object.
An sf-object with a sfc_POINTgeometry column and another
weighting column.
If available, a polygon containing a buffer plot boundary.
buffer has to be a length one sfc_POLYGON-object. Relevant to
decide which assignments of grid cells to points are critical.
Character vector of length one. This column of the
point dataset will be used as weight. If left out, an unweighted
Voronoi Diagram will be calculated.
Character vector specifying additional columns in /codepoint that will be added as separate classes to the output /codeRaster-object.
A numeric vector of length one specifying the resolution of the output grid
Issue a warning if the coordinate system is not metric (which is not tested).
A RasterStack-object.